# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from ElasticEmail.models.delivery_optimization_type import DeliveryOptimizationType
from ElasticEmail.models.split_options import SplitOptions
from typing import Optional, Set
from typing_extensions import Self

class CampaignOptions(BaseModel):
    """
    Different send options for a Campaign
    """ # noqa: E501
    delivery_optimization: Optional[DeliveryOptimizationType] = Field(default=None, alias="DeliveryOptimization")
    track_opens: Optional[StrictBool] = Field(default=None, description="Should the opens be tracked? If no value has been provided, Account's default setting will be used.", alias="TrackOpens")
    track_clicks: Optional[StrictBool] = Field(default=None, description="Should the clicks be tracked? If no value has been provided, Account's default setting will be used.", alias="TrackClicks")
    schedule_for: Optional[datetime] = Field(default=None, description="Date when this Campaign is scheduled to be sent on", alias="ScheduleFor")
    trigger_frequency: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="How often (in minutes) to send the campaign", alias="TriggerFrequency")
    trigger_count: Optional[StrictInt] = Field(default=None, description="How many times send the campaign", alias="TriggerCount")
    split_options: Optional[SplitOptions] = Field(default=None, alias="SplitOptions")
    __properties: ClassVar[List[str]] = ["DeliveryOptimization", "TrackOpens", "TrackClicks", "ScheduleFor", "TriggerFrequency", "TriggerCount", "SplitOptions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CampaignOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of split_options
        if self.split_options:
            _dict['SplitOptions'] = self.split_options.to_dict()
        # set to None if track_opens (nullable) is None
        # and model_fields_set contains the field
        if self.track_opens is None and "track_opens" in self.model_fields_set:
            _dict['TrackOpens'] = None

        # set to None if track_clicks (nullable) is None
        # and model_fields_set contains the field
        if self.track_clicks is None and "track_clicks" in self.model_fields_set:
            _dict['TrackClicks'] = None

        # set to None if schedule_for (nullable) is None
        # and model_fields_set contains the field
        if self.schedule_for is None and "schedule_for" in self.model_fields_set:
            _dict['ScheduleFor'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CampaignOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "DeliveryOptimization": obj.get("DeliveryOptimization"),
            "TrackOpens": obj.get("TrackOpens"),
            "TrackClicks": obj.get("TrackClicks"),
            "ScheduleFor": obj.get("ScheduleFor"),
            "TriggerFrequency": obj.get("TriggerFrequency"),
            "TriggerCount": obj.get("TriggerCount"),
            "SplitOptions": SplitOptions.from_dict(obj["SplitOptions"]) if obj.get("SplitOptions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AccessLevel(str, Enum):
    """
    AccessLevel
    """

    """
    allowed enum values
    """
    NONE = 'None'
    VIEWACCOUNT = 'ViewAccount'
    VIEWCONTACTS = 'ViewContacts'
    VIEWFORMS = 'ViewForms'
    VIEWTEMPLATES = 'ViewTemplates'
    VIEWCAMPAIGNS = 'ViewCampaigns'
    VIEWCHANNELS = 'ViewChannels'
    VIEWAUTOMATIONS = 'ViewAutomations'
    VIEWSURVEYS = 'ViewSurveys'
    VIEWSETTINGS = 'ViewSettings'
    VIEWBILLING = 'ViewBilling'
    VIEWSUBACCOUNTS = 'ViewSubAccounts'
    VIEWUSERS = 'ViewUsers'
    VIEWFILES = 'ViewFiles'
    VIEWREPORTS = 'ViewReports'
    MODIFYACCOUNT = 'ModifyAccount'
    MODIFYCONTACTS = 'ModifyContacts'
    MODIFYFORMS = 'ModifyForms'
    MODIFYTEMPLATES = 'ModifyTemplates'
    MODIFYCAMPAIGNS = 'ModifyCampaigns'
    MODIFYCHANNELS = 'ModifyChannels'
    MODIFYAUTOMATIONS = 'ModifyAutomations'
    MODIFYSURVEYS = 'ModifySurveys'
    MODIFYFILES = 'ModifyFiles'
    EXPORT = 'Export'
    SENDSMTP = 'SendSmtp'
    SENDSMS = 'SendSMS'
    MODIFYSETTINGS = 'ModifySettings'
    MODIFYBILLING = 'ModifyBilling'
    MODIFYPROFILE = 'ModifyProfile'
    MODIFYSUBACCOUNTS = 'ModifySubAccounts'
    MODIFYUSERS = 'ModifyUsers'
    SECURITY = 'Security'
    MODIFYLANGUAGE = 'ModifyLanguage'
    VIEWSUPPORT = 'ViewSupport'
    SENDHTTP = 'SendHttp'
    MODIFY2FAEMAIL = 'Modify2FAEmail'
    MODIFYSUPPORT = 'ModifySupport'
    VIEWCUSTOMFIELDS = 'ViewCustomFields'
    MODIFYCUSTOMFIELDS = 'ModifyCustomFields'
    MODIFYWEBNOTIFICATIONS = 'ModifyWebNotifications'
    EXTENDEDLOGS = 'ExtendedLogs'
    VERIFYEMAILS = 'VerifyEmails'
    MODIFY2FASMS = 'Modify2FASms'
    MODIFYLANDINGPAGES = 'ModifyLandingPages'
    VIEWLANDINGPAGES = 'ViewLandingPages'
    MODIFYSUPPRESSIONS = 'ModifySuppressions'
    VIEWSUPPRESSIONS = 'ViewSuppressions'
    VIEWDRAGDROPEDITOR = 'ViewDragDropEditor'
    VIEWTEMPLATEEDITOR = 'ViewTemplateEditor'
    VIEWAITOOLS = 'ViewAITools'
    MODIFYSUBSCRIPTIONANTISPAM = 'ModifySubscriptionAntiSpam'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AccessLevel from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

# flake8: noqa
"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ElasticEmail.models.access_level import AccessLevel
from ElasticEmail.models.account_status_enum import AccountStatusEnum
from ElasticEmail.models.api_key import ApiKey
from ElasticEmail.models.api_key_payload import ApiKeyPayload
from ElasticEmail.models.body_content_type import BodyContentType
from ElasticEmail.models.body_part import BodyPart
from ElasticEmail.models.campaign import Campaign
from ElasticEmail.models.campaign_options import CampaignOptions
from ElasticEmail.models.campaign_recipient import CampaignRecipient
from ElasticEmail.models.campaign_status import CampaignStatus
from ElasticEmail.models.campaign_template import CampaignTemplate
from ElasticEmail.models.certificate_validation_status import CertificateValidationStatus
from ElasticEmail.models.channel_log_status_summary import ChannelLogStatusSummary
from ElasticEmail.models.compression_format import CompressionFormat
from ElasticEmail.models.consent_data import ConsentData
from ElasticEmail.models.consent_tracking import ConsentTracking
from ElasticEmail.models.contact import Contact
from ElasticEmail.models.contact_activity import ContactActivity
from ElasticEmail.models.contact_payload import ContactPayload
from ElasticEmail.models.contact_source import ContactSource
from ElasticEmail.models.contact_status import ContactStatus
from ElasticEmail.models.contact_update_payload import ContactUpdatePayload
from ElasticEmail.models.contacts_list import ContactsList
from ElasticEmail.models.delivery_optimization_type import DeliveryOptimizationType
from ElasticEmail.models.domain_data import DomainData
from ElasticEmail.models.domain_detail import DomainDetail
from ElasticEmail.models.domain_owner import DomainOwner
from ElasticEmail.models.domain_payload import DomainPayload
from ElasticEmail.models.domain_update_payload import DomainUpdatePayload
from ElasticEmail.models.email_content import EmailContent
from ElasticEmail.models.email_data import EmailData
from ElasticEmail.models.email_job_failed_status import EmailJobFailedStatus
from ElasticEmail.models.email_job_status import EmailJobStatus
from ElasticEmail.models.email_message_data import EmailMessageData
from ElasticEmail.models.email_predicted_validation_status import EmailPredictedValidationStatus
from ElasticEmail.models.email_recipient import EmailRecipient
from ElasticEmail.models.email_send import EmailSend
from ElasticEmail.models.email_status import EmailStatus
from ElasticEmail.models.email_transactional_message_data import EmailTransactionalMessageData
from ElasticEmail.models.email_validation_result import EmailValidationResult
from ElasticEmail.models.email_validation_status import EmailValidationStatus
from ElasticEmail.models.email_view import EmailView
from ElasticEmail.models.emails_payload import EmailsPayload
from ElasticEmail.models.encoding_type import EncodingType
from ElasticEmail.models.event_type import EventType
from ElasticEmail.models.events_order_by import EventsOrderBy
from ElasticEmail.models.export_file_formats import ExportFileFormats
from ElasticEmail.models.export_link import ExportLink
from ElasticEmail.models.export_status import ExportStatus
from ElasticEmail.models.file_info import FileInfo
from ElasticEmail.models.file_payload import FilePayload
from ElasticEmail.models.file_upload_result import FileUploadResult
from ElasticEmail.models.inbound_payload import InboundPayload
from ElasticEmail.models.inbound_route import InboundRoute
from ElasticEmail.models.inbound_route_action_type import InboundRouteActionType
from ElasticEmail.models.inbound_route_filter_type import InboundRouteFilterType
from ElasticEmail.models.list_payload import ListPayload
from ElasticEmail.models.list_update_payload import ListUpdatePayload
from ElasticEmail.models.log_job_status import LogJobStatus
from ElasticEmail.models.log_status_summary import LogStatusSummary
from ElasticEmail.models.merge_email_payload import MergeEmailPayload
from ElasticEmail.models.message_attachment import MessageAttachment
from ElasticEmail.models.message_category import MessageCategory
from ElasticEmail.models.message_category_enum import MessageCategoryEnum
from ElasticEmail.models.new_api_key import NewApiKey
from ElasticEmail.models.new_smtp_credentials import NewSmtpCredentials
from ElasticEmail.models.options import Options
from ElasticEmail.models.recipient_event import RecipientEvent
from ElasticEmail.models.segment import Segment
from ElasticEmail.models.segment_payload import SegmentPayload
from ElasticEmail.models.smtp_credentials import SmtpCredentials
from ElasticEmail.models.smtp_credentials_payload import SmtpCredentialsPayload
from ElasticEmail.models.sort_order_item import SortOrderItem
from ElasticEmail.models.split_optimization_type import SplitOptimizationType
from ElasticEmail.models.split_options import SplitOptions
from ElasticEmail.models.sub_account_info import SubAccountInfo
from ElasticEmail.models.subaccount_email_credits_payload import SubaccountEmailCreditsPayload
from ElasticEmail.models.subaccount_email_settings import SubaccountEmailSettings
from ElasticEmail.models.subaccount_email_settings_payload import SubaccountEmailSettingsPayload
from ElasticEmail.models.subaccount_payload import SubaccountPayload
from ElasticEmail.models.subaccount_settings_info import SubaccountSettingsInfo
from ElasticEmail.models.subaccount_settings_info_payload import SubaccountSettingsInfoPayload
from ElasticEmail.models.suppression import Suppression
from ElasticEmail.models.template import Template
from ElasticEmail.models.template_payload import TemplatePayload
from ElasticEmail.models.template_scope import TemplateScope
from ElasticEmail.models.template_type import TemplateType
from ElasticEmail.models.tracking_type import TrackingType
from ElasticEmail.models.tracking_validation_status import TrackingValidationStatus
from ElasticEmail.models.transactional_recipient import TransactionalRecipient
from ElasticEmail.models.utm import Utm
from ElasticEmail.models.verification_file_result import VerificationFileResult
from ElasticEmail.models.verification_file_result_details import VerificationFileResultDetails
from ElasticEmail.models.verification_status import VerificationStatus



# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBytes, StrictInt, StrictStr
from typing import List, Optional, Union
from typing_extensions import Annotated
from ElasticEmail.models.compression_format import CompressionFormat
from ElasticEmail.models.contact import Contact
from ElasticEmail.models.contact_payload import ContactPayload
from ElasticEmail.models.contact_update_payload import ContactUpdatePayload
from ElasticEmail.models.emails_payload import EmailsPayload
from ElasticEmail.models.export_file_formats import ExportFileFormats
from ElasticEmail.models.export_link import ExportLink
from ElasticEmail.models.export_status import ExportStatus

from ElasticEmail.api_client import ApiClient, RequestSerialized
from ElasticEmail.api_response import ApiResponse
from ElasticEmail.rest import RESTResponseType


class ContactsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def contacts_by_email_delete(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Contact

        Deletes the provided contact. Required Access Level: ModifyContacts

        :param email: Proper email address. (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_delete_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_by_email_delete_with_http_info(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Contact

        Deletes the provided contact. Required Access Level: ModifyContacts

        :param email: Proper email address. (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_delete_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_by_email_delete_without_preload_content(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Contact

        Deletes the provided contact. Required Access Level: ModifyContacts

        :param email: Proper email address. (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_delete_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_by_email_delete_serialize(
        self,
        email,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if email is not None:
            _path_params['email'] = email
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/contacts/{email}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_by_email_get(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Contact:
        """Load Contact

        Load detailed contact information for specified email. Required Access Level: ViewContacts

        :param email: Proper email address. (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_get_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Contact",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_by_email_get_with_http_info(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Contact]:
        """Load Contact

        Load detailed contact information for specified email. Required Access Level: ViewContacts

        :param email: Proper email address. (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_get_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Contact",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_by_email_get_without_preload_content(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Load Contact

        Load detailed contact information for specified email. Required Access Level: ViewContacts

        :param email: Proper email address. (required)
        :type email: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_get_serialize(
            email=email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Contact",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_by_email_get_serialize(
        self,
        email,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if email is not None:
            _path_params['email'] = email
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/contacts/{email}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_by_email_put(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        contact_update_payload: ContactUpdatePayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Contact:
        """Update Contact

        Update selected contact. Omitted contact's fields will not be changed. Required Access Level: ModifyContacts

        :param email: Proper email address. (required)
        :type email: str
        :param contact_update_payload: (required)
        :type contact_update_payload: ContactUpdatePayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_put_serialize(
            email=email,
            contact_update_payload=contact_update_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Contact",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_by_email_put_with_http_info(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        contact_update_payload: ContactUpdatePayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Contact]:
        """Update Contact

        Update selected contact. Omitted contact's fields will not be changed. Required Access Level: ModifyContacts

        :param email: Proper email address. (required)
        :type email: str
        :param contact_update_payload: (required)
        :type contact_update_payload: ContactUpdatePayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_put_serialize(
            email=email,
            contact_update_payload=contact_update_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Contact",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_by_email_put_without_preload_content(
        self,
        email: Annotated[StrictStr, Field(description="Proper email address.")],
        contact_update_payload: ContactUpdatePayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Contact

        Update selected contact. Omitted contact's fields will not be changed. Required Access Level: ModifyContacts

        :param email: Proper email address. (required)
        :type email: str
        :param contact_update_payload: (required)
        :type contact_update_payload: ContactUpdatePayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_by_email_put_serialize(
            email=email,
            contact_update_payload=contact_update_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Contact",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_by_email_put_serialize(
        self,
        email,
        contact_update_payload,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if email is not None:
            _path_params['email'] = email
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if contact_update_payload is not None:
            _body_params = contact_update_payload


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/contacts/{email}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_delete_post(
        self,
        emails_payload: Annotated[EmailsPayload, Field(description="Provide either rule or a list of emails, not both.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Contacts Bulk

        Deletes provided contacts in bulk. Required Access Level: ModifyContacts

        :param emails_payload: Provide either rule or a list of emails, not both. (required)
        :type emails_payload: EmailsPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_delete_post_serialize(
            emails_payload=emails_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_delete_post_with_http_info(
        self,
        emails_payload: Annotated[EmailsPayload, Field(description="Provide either rule or a list of emails, not both.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Contacts Bulk

        Deletes provided contacts in bulk. Required Access Level: ModifyContacts

        :param emails_payload: Provide either rule or a list of emails, not both. (required)
        :type emails_payload: EmailsPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_delete_post_serialize(
            emails_payload=emails_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_delete_post_without_preload_content(
        self,
        emails_payload: Annotated[EmailsPayload, Field(description="Provide either rule or a list of emails, not both.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Contacts Bulk

        Deletes provided contacts in bulk. Required Access Level: ModifyContacts

        :param emails_payload: Provide either rule or a list of emails, not both. (required)
        :type emails_payload: EmailsPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_delete_post_serialize(
            emails_payload=emails_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_delete_post_serialize(
        self,
        emails_payload,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if emails_payload is not None:
            _body_params = emails_payload



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/contacts/delete',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_export_by_id_status_get(
        self,
        id: Annotated[StrictStr, Field(description="ID of the exported file")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ExportStatus:
        """Check Export Status

        Check the current status of the export. Required Access Level: Export

        :param id: ID of the exported file (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_export_by_id_status_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ExportStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_export_by_id_status_get_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of the exported file")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ExportStatus]:
        """Check Export Status

        Check the current status of the export. Required Access Level: Export

        :param id: ID of the exported file (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_export_by_id_status_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ExportStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_export_by_id_status_get_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of the exported file")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Check Export Status

        Check the current status of the export. Required Access Level: Export

        :param id: ID of the exported file (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_export_by_id_status_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ExportStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_export_by_id_status_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/contacts/export/{id}/status',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_export_post(
        self,
        file_format: Annotated[Optional[ExportFileFormats], Field(description="Format of the exported file")] = None,
        rule: Annotated[Optional[StrictStr], Field(description="Query used for filtering.")] = None,
        emails: Annotated[Optional[List[StrictStr]], Field(description="Comma delimited list of contact emails")] = None,
        compression_format: Annotated[Optional[CompressionFormat], Field(description="FileResponse compression format. None or Zip.")] = None,
        file_name: Annotated[Optional[StrictStr], Field(description="Name of your file including extension.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ExportLink:
        """Export Contacts

        Request an Export of specified Contacts. Required Access Level: Export

        :param file_format: Format of the exported file
        :type file_format: ExportFileFormats
        :param rule: Query used for filtering.
        :type rule: str
        :param emails: Comma delimited list of contact emails
        :type emails: List[str]
        :param compression_format: FileResponse compression format. None or Zip.
        :type compression_format: CompressionFormat
        :param file_name: Name of your file including extension.
        :type file_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_export_post_serialize(
            file_format=file_format,
            rule=rule,
            emails=emails,
            compression_format=compression_format,
            file_name=file_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "ExportLink",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_export_post_with_http_info(
        self,
        file_format: Annotated[Optional[ExportFileFormats], Field(description="Format of the exported file")] = None,
        rule: Annotated[Optional[StrictStr], Field(description="Query used for filtering.")] = None,
        emails: Annotated[Optional[List[StrictStr]], Field(description="Comma delimited list of contact emails")] = None,
        compression_format: Annotated[Optional[CompressionFormat], Field(description="FileResponse compression format. None or Zip.")] = None,
        file_name: Annotated[Optional[StrictStr], Field(description="Name of your file including extension.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ExportLink]:
        """Export Contacts

        Request an Export of specified Contacts. Required Access Level: Export

        :param file_format: Format of the exported file
        :type file_format: ExportFileFormats
        :param rule: Query used for filtering.
        :type rule: str
        :param emails: Comma delimited list of contact emails
        :type emails: List[str]
        :param compression_format: FileResponse compression format. None or Zip.
        :type compression_format: CompressionFormat
        :param file_name: Name of your file including extension.
        :type file_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_export_post_serialize(
            file_format=file_format,
            rule=rule,
            emails=emails,
            compression_format=compression_format,
            file_name=file_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "ExportLink",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_export_post_without_preload_content(
        self,
        file_format: Annotated[Optional[ExportFileFormats], Field(description="Format of the exported file")] = None,
        rule: Annotated[Optional[StrictStr], Field(description="Query used for filtering.")] = None,
        emails: Annotated[Optional[List[StrictStr]], Field(description="Comma delimited list of contact emails")] = None,
        compression_format: Annotated[Optional[CompressionFormat], Field(description="FileResponse compression format. None or Zip.")] = None,
        file_name: Annotated[Optional[StrictStr], Field(description="Name of your file including extension.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Export Contacts

        Request an Export of specified Contacts. Required Access Level: Export

        :param file_format: Format of the exported file
        :type file_format: ExportFileFormats
        :param rule: Query used for filtering.
        :type rule: str
        :param emails: Comma delimited list of contact emails
        :type emails: List[str]
        :param compression_format: FileResponse compression format. None or Zip.
        :type compression_format: CompressionFormat
        :param file_name: Name of your file including extension.
        :type file_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_export_post_serialize(
            file_format=file_format,
            rule=rule,
            emails=emails,
            compression_format=compression_format,
            file_name=file_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "ExportLink",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_export_post_serialize(
        self,
        file_format,
        rule,
        emails,
        compression_format,
        file_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'emails': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if file_format is not None:
            
            _query_params.append(('fileFormat', file_format.value))
            
        if rule is not None:
            
            _query_params.append(('rule', rule))
            
        if emails is not None:
            
            _query_params.append(('emails', emails))
            
        if compression_format is not None:
            
            _query_params.append(('compressionFormat', compression_format.value))
            
        if file_name is not None:
            
            _query_params.append(('fileName', file_name))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/contacts/export',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_get(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of returned items.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="How many items should be returned ahead.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Contact]:
        """Load Contacts

        Returns a list of contacts. Required Access Level: ViewContacts

        :param limit: Maximum number of returned items.
        :type limit: int
        :param offset: How many items should be returned ahead.
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Contact]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_get_with_http_info(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of returned items.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="How many items should be returned ahead.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Contact]]:
        """Load Contacts

        Returns a list of contacts. Required Access Level: ViewContacts

        :param limit: Maximum number of returned items.
        :type limit: int
        :param offset: How many items should be returned ahead.
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Contact]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_get_without_preload_content(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of returned items.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="How many items should be returned ahead.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Load Contacts

        Returns a list of contacts. Required Access Level: ViewContacts

        :param limit: Maximum number of returned items.
        :type limit: int
        :param offset: How many items should be returned ahead.
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Contact]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_get_serialize(
        self,
        limit,
        offset,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/contacts',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_import_post(
        self,
        list_name: Annotated[Optional[StrictStr], Field(description="Name of an existing list to add these contacts to")] = None,
        encoding_name: Annotated[Optional[StrictStr], Field(description="In what encoding the file is uploaded")] = None,
        file_url: Annotated[Optional[StrictStr], Field(description="Optional url of csv to import")] = None,
        file: Optional[Union[StrictBytes, StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Upload Contacts

        Upload contacts from a file. Required Access Level: ModifyContacts

        :param list_name: Name of an existing list to add these contacts to
        :type list_name: str
        :param encoding_name: In what encoding the file is uploaded
        :type encoding_name: str
        :param file_url: Optional url of csv to import
        :type file_url: str
        :param file:
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_import_post_serialize(
            list_name=list_name,
            encoding_name=encoding_name,
            file_url=file_url,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_import_post_with_http_info(
        self,
        list_name: Annotated[Optional[StrictStr], Field(description="Name of an existing list to add these contacts to")] = None,
        encoding_name: Annotated[Optional[StrictStr], Field(description="In what encoding the file is uploaded")] = None,
        file_url: Annotated[Optional[StrictStr], Field(description="Optional url of csv to import")] = None,
        file: Optional[Union[StrictBytes, StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Upload Contacts

        Upload contacts from a file. Required Access Level: ModifyContacts

        :param list_name: Name of an existing list to add these contacts to
        :type list_name: str
        :param encoding_name: In what encoding the file is uploaded
        :type encoding_name: str
        :param file_url: Optional url of csv to import
        :type file_url: str
        :param file:
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_import_post_serialize(
            list_name=list_name,
            encoding_name=encoding_name,
            file_url=file_url,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_import_post_without_preload_content(
        self,
        list_name: Annotated[Optional[StrictStr], Field(description="Name of an existing list to add these contacts to")] = None,
        encoding_name: Annotated[Optional[StrictStr], Field(description="In what encoding the file is uploaded")] = None,
        file_url: Annotated[Optional[StrictStr], Field(description="Optional url of csv to import")] = None,
        file: Optional[Union[StrictBytes, StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload Contacts

        Upload contacts from a file. Required Access Level: ModifyContacts

        :param list_name: Name of an existing list to add these contacts to
        :type list_name: str
        :param encoding_name: In what encoding the file is uploaded
        :type encoding_name: str
        :param file_url: Optional url of csv to import
        :type file_url: str
        :param file:
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_import_post_serialize(
            list_name=list_name,
            encoding_name=encoding_name,
            file_url=file_url,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_import_post_serialize(
        self,
        list_name,
        encoding_name,
        file_url,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if list_name is not None:
            
            _query_params.append(('listName', list_name))
            
        if encoding_name is not None:
            
            _query_params.append(('encodingName', encoding_name))
            
        if file_url is not None:
            
            _query_params.append(('fileUrl', file_url))
            
        # process the header parameters
        # process the form parameters
        if file is not None:
            _files['file'] = file
        # process the body parameter



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/contacts/import',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def contacts_post(
        self,
        contact_payload: List[ContactPayload],
        listnames: Annotated[Optional[List[StrictStr]], Field(description="Names of lists to which the uploaded contacts should be added to")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Contact]:
        """Add Contact

        Add new Contacts to your Lists. Up to 1000 can be added (for more please refer to the import request). Required Access Level: ModifyContacts

        :param contact_payload: (required)
        :type contact_payload: List[ContactPayload]
        :param listnames: Names of lists to which the uploaded contacts should be added to
        :type listnames: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_post_serialize(
            contact_payload=contact_payload,
            listnames=listnames,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Contact]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def contacts_post_with_http_info(
        self,
        contact_payload: List[ContactPayload],
        listnames: Annotated[Optional[List[StrictStr]], Field(description="Names of lists to which the uploaded contacts should be added to")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Contact]]:
        """Add Contact

        Add new Contacts to your Lists. Up to 1000 can be added (for more please refer to the import request). Required Access Level: ModifyContacts

        :param contact_payload: (required)
        :type contact_payload: List[ContactPayload]
        :param listnames: Names of lists to which the uploaded contacts should be added to
        :type listnames: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_post_serialize(
            contact_payload=contact_payload,
            listnames=listnames,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Contact]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def contacts_post_without_preload_content(
        self,
        contact_payload: List[ContactPayload],
        listnames: Annotated[Optional[List[StrictStr]], Field(description="Names of lists to which the uploaded contacts should be added to")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Add Contact

        Add new Contacts to your Lists. Up to 1000 can be added (for more please refer to the import request). Required Access Level: ModifyContacts

        :param contact_payload: (required)
        :type contact_payload: List[ContactPayload]
        :param listnames: Names of lists to which the uploaded contacts should be added to
        :type listnames: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._contacts_post_serialize(
            contact_payload=contact_payload,
            listnames=listnames,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Contact]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _contacts_post_serialize(
        self,
        contact_payload,
        listnames,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'ContactPayload': '',
            'listnames': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if listnames is not None:
            
            _query_params.append(('listnames', listnames))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if contact_payload is not None:
            _body_params = contact_payload


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apikey'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/contacts',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ElasticEmail.models.certificate_validation_status import CertificateValidationStatus
from ElasticEmail.models.domain_owner import DomainOwner
from ElasticEmail.models.tracking_type import TrackingType
from ElasticEmail.models.tracking_validation_status import TrackingValidationStatus
from typing import Optional, Set
from typing_extensions import Self

class DomainDetail(BaseModel):
    """
    Domain data, with information about domain records.
    """ # noqa: E501
    domain: Optional[StrictStr] = Field(default=None, description="Name of selected domain.", alias="Domain")
    default_domain: Optional[StrictBool] = Field(default=None, description="True, if domain is used as default. Otherwise, false,", alias="DefaultDomain")
    spf: Optional[StrictBool] = Field(default=None, description="True, if SPF record is verified", alias="Spf")
    dkim: Optional[StrictBool] = Field(default=None, description="True, if DKIM record is verified", alias="Dkim")
    mx: Optional[StrictBool] = Field(default=None, description="True, if MX record is verified", alias="MX")
    dmarc: Optional[StrictBool] = Field(default=None, alias="DMARC")
    is_rewrite_domain_valid: Optional[StrictBool] = Field(default=None, description="True, if tracking CNAME record is verified", alias="IsRewriteDomainValid")
    verify: Optional[StrictBool] = Field(default=None, description="True, if DKIM, SPF, or tracking are still to be verified", alias="Verify")
    type: Optional[TrackingType] = Field(default=None, alias="Type")
    tracking_status: Optional[TrackingValidationStatus] = Field(default=None, alias="TrackingStatus")
    certificate_status: Optional[CertificateValidationStatus] = Field(default=None, alias="CertificateStatus")
    certificate_validation_error: Optional[StrictStr] = Field(default=None, alias="CertificateValidationError")
    tracking_type_user_request: Optional[TrackingType] = Field(default=None, alias="TrackingTypeUserRequest")
    verp: Optional[StrictBool] = Field(default=None, alias="VERP")
    custom_bounces_domain: Optional[StrictStr] = Field(default=None, alias="CustomBouncesDomain")
    is_custom_bounces_domain_default: Optional[StrictBool] = Field(default=None, alias="IsCustomBouncesDomainDefault")
    is_marked_for_deletion: Optional[StrictBool] = Field(default=None, alias="IsMarkedForDeletion")
    ownership: Optional[DomainOwner] = Field(default=None, alias="Ownership")
    __properties: ClassVar[List[str]] = ["Domain", "DefaultDomain", "Spf", "Dkim", "MX", "DMARC", "IsRewriteDomainValid", "Verify", "Type", "TrackingStatus", "CertificateStatus", "CertificateValidationError", "TrackingTypeUserRequest", "VERP", "CustomBouncesDomain", "IsCustomBouncesDomainDefault", "IsMarkedForDeletion", "Ownership"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DomainDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DomainDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "Domain": obj.get("Domain"),
            "DefaultDomain": obj.get("DefaultDomain"),
            "Spf": obj.get("Spf"),
            "Dkim": obj.get("Dkim"),
            "MX": obj.get("MX"),
            "DMARC": obj.get("DMARC"),
            "IsRewriteDomainValid": obj.get("IsRewriteDomainValid"),
            "Verify": obj.get("Verify"),
            "Type": obj.get("Type"),
            "TrackingStatus": obj.get("TrackingStatus"),
            "CertificateStatus": obj.get("CertificateStatus"),
            "CertificateValidationError": obj.get("CertificateValidationError"),
            "TrackingTypeUserRequest": obj.get("TrackingTypeUserRequest"),
            "VERP": obj.get("VERP"),
            "CustomBouncesDomain": obj.get("CustomBouncesDomain"),
            "IsCustomBouncesDomainDefault": obj.get("IsCustomBouncesDomainDefault"),
            "IsMarkedForDeletion": obj.get("IsMarkedForDeletion"),
            "Ownership": obj.get("Ownership")
        })
        return _obj





# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ElasticEmail.models.email_job_failed_status import EmailJobFailedStatus
from typing import Optional, Set
from typing_extensions import Self

class EmailJobStatus(BaseModel):
    """
    EmailJobStatus
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="ID number of your attachment", alias="ID")
    status: Optional[StrictStr] = Field(default=None, description="Name of status: submitted, complete, in_progress", alias="Status")
    recipients_count: Optional[StrictInt] = Field(default=None, alias="RecipientsCount")
    failed: Optional[List[EmailJobFailedStatus]] = Field(default=None, alias="Failed")
    failed_count: Optional[StrictInt] = Field(default=None, description="Total emails failed.", alias="FailedCount")
    sent: Optional[List[StrictStr]] = Field(default=None, alias="Sent")
    sent_count: Optional[StrictInt] = Field(default=None, description="Total emails sent.", alias="SentCount")
    delivered: Optional[List[StrictStr]] = Field(default=None, description="Number of delivered messages", alias="Delivered")
    delivered_count: Optional[StrictInt] = Field(default=None, alias="DeliveredCount")
    pending: Optional[List[StrictStr]] = Field(default=None, alias="Pending")
    pending_count: Optional[StrictInt] = Field(default=None, alias="PendingCount")
    opened: Optional[List[StrictStr]] = Field(default=None, description="Number of opened messages", alias="Opened")
    opened_count: Optional[StrictInt] = Field(default=None, description="Total emails opened.", alias="OpenedCount")
    clicked: Optional[List[StrictStr]] = Field(default=None, description="Number of clicked messages", alias="Clicked")
    clicked_count: Optional[StrictInt] = Field(default=None, description="Total emails clicked", alias="ClickedCount")
    unsubscribed: Optional[List[StrictStr]] = Field(default=None, description="Number of unsubscribed messages", alias="Unsubscribed")
    unsubscribed_count: Optional[StrictInt] = Field(default=None, description="Total emails unsubscribed", alias="UnsubscribedCount")
    abuse_reports: Optional[List[StrictStr]] = Field(default=None, alias="AbuseReports")
    abuse_reports_count: Optional[StrictInt] = Field(default=None, alias="AbuseReportsCount")
    message_ids: Optional[List[StrictStr]] = Field(default=None, description="List of all MessageIDs for this job.", alias="MessageIDs")
    __properties: ClassVar[List[str]] = ["ID", "Status", "RecipientsCount", "Failed", "FailedCount", "Sent", "SentCount", "Delivered", "DeliveredCount", "Pending", "PendingCount", "Opened", "OpenedCount", "Clicked", "ClickedCount", "Unsubscribed", "UnsubscribedCount", "AbuseReports", "AbuseReportsCount", "MessageIDs"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EmailJobStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in failed (list)
        _items = []
        if self.failed:
            for _item in self.failed:
                if _item:
                    _items.append(_item.to_dict())
            _dict['Failed'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EmailJobStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ID": obj.get("ID"),
            "Status": obj.get("Status"),
            "RecipientsCount": obj.get("RecipientsCount"),
            "Failed": [EmailJobFailedStatus.from_dict(_item) for _item in obj["Failed"]] if obj.get("Failed") is not None else None,
            "FailedCount": obj.get("FailedCount"),
            "Sent": obj.get("Sent"),
            "SentCount": obj.get("SentCount"),
            "Delivered": obj.get("Delivered"),
            "DeliveredCount": obj.get("DeliveredCount"),
            "Pending": obj.get("Pending"),
            "PendingCount": obj.get("PendingCount"),
            "Opened": obj.get("Opened"),
            "OpenedCount": obj.get("OpenedCount"),
            "Clicked": obj.get("Clicked"),
            "ClickedCount": obj.get("ClickedCount"),
            "Unsubscribed": obj.get("Unsubscribed"),
            "UnsubscribedCount": obj.get("UnsubscribedCount"),
            "AbuseReports": obj.get("AbuseReports"),
            "AbuseReportsCount": obj.get("AbuseReportsCount"),
            "MessageIDs": obj.get("MessageIDs")
        })
        return _obj





# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ElasticEmail.models.verification_file_result_details import VerificationFileResultDetails

class TestVerificationFileResultDetails(unittest.TestCase):
    """VerificationFileResultDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VerificationFileResultDetails:
        """Test VerificationFileResultDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VerificationFileResultDetails`
        """
        model = VerificationFileResultDetails()
        if include_optional:
            return VerificationFileResultDetails(
                verification_result = [
                    ElasticEmail.models.email_validation_result.EmailValidationResult(
                        account = '', 
                        domain = 'example.com', 
                        email = '', 
                        suggested_spelling = '', 
                        disposable = True, 
                        role = True, 
                        reason = '', 
                        date_added = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        result = 'None', 
                        predicted_score = 1.337, 
                        predicted_status = 'None', )
                    ],
                verification_id = '',
                filename = '',
                verification_status = 'Processing',
                file_upload_result = ElasticEmail.models.file_upload_result.FileUploadResult(
                    emails_count = 56, 
                    duplicated_emails_count = 56, ),
                date_added = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                source = ''
            )
        else:
            return VerificationFileResultDetails(
        )
        """

    def testVerificationFileResultDetails(self):
        """Test VerificationFileResultDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class SortOrderItem(BaseModel):
    """
    Change the ordering of this inbound route for when matching the inbound
    """ # noqa: E501
    public_inbound_id: StrictStr = Field(description="ID of the route to change the order of", alias="PublicInboundId")
    sort_order: StrictInt = Field(description="1 - route will be used first", alias="SortOrder")
    __properties: ClassVar[List[str]] = ["PublicInboundId", "SortOrder"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SortOrderItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SortOrderItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "PublicInboundId": obj.get("PublicInboundId"),
            "SortOrder": obj.get("SortOrder")
        })
        return _obj





# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ElasticEmail.models.campaign_options import CampaignOptions

class TestCampaignOptions(unittest.TestCase):
    """CampaignOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CampaignOptions:
        """Test CampaignOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CampaignOptions`
        """
        model = CampaignOptions()
        if include_optional:
            return CampaignOptions(
                delivery_optimization = 'None',
                track_opens = True,
                track_clicks = True,
                schedule_for = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                trigger_frequency = 1.337,
                trigger_count = 56,
                split_options = ElasticEmail.models.split_options.SplitOptions(
                    optimize_for = 'Opens', 
                    optimize_period_minutes = 30, )
            )
        else:
            return CampaignOptions(
        )
        """

    def testCampaignOptions(self):
        """Test CampaignOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
